@@ -17,6 +17,7 @@ class BaseProtocol(ABC):
 
     def __init__(self, **kwargs):
         station = kwargs.get('code')
+        self.source = kwargs.get("source", socket.SOCK_STREAM)
         self.sock = kwargs.get('sock')
         self.timeout = kwargs.get('timeout', 1)
         self.raise_timeout = kwargs.get('raise_timeout', False)
@@ -68,7 +69,7 @@ class BaseProtocol(ABC):
         sock = None
         if sock is None:
             sock = socket.socket(
-                socket.AF_INET, socket.SOCK_STREAM)
+                socket.AF_INET, self.source)
         else:
             sock = sock
         return sock
@@ -90,7 +91,6 @@ class BaseProtocol(ABC):
                 counter = 0
             try:
                 future_open_conn = asyncio.open_connection(
-                    loop=loop,
                     host=host,
                     port=port)
                 (reader, writer) = await asyncio.wait_for(
@@ -135,7 +135,7 @@ class BaseProtocol(ABC):
                     f"Excepción por desconexión {conn_error}")
                 raise conn_error
             except Exception as e:
-                msg = f"Excepción no considerada e"
+                msg = f"Excepción no considerada {e}, {self.station}"
                 print(msg)
                 self.logger.exception(msg)
                 raise e
@@ -177,7 +177,7 @@ class BaseProtocol(ABC):
                         "Excepción por desconexión {conn_error}, station {self.station}")
                     await asyncio.sleep(5)
                 except Exception as e:
-                    print(f"Excepción no considerada, {e}")
+                    print(f"Excepción no considerada, {e} heart beat")
                     self.logger.exception(
                         f"Excepción no considerada {e}, station {self.station}")
                     await asyncio.sleep(5)
@@ -258,7 +258,7 @@ class BaseProtocol(ABC):
                 {conn_error}""")
             raise conn_error
         except Exception as e:
-            print("Excepción no considerada")
+            print("Excepción no considerada async close")
             self.logger.exception(
                 f"Close->Excepción no considerada al intentar leer e")
             raise e
@@ -306,7 +306,7 @@ class BaseProtocol(ABC):
                 {conn_error}""")
             raise conn_error
         except Exception as e:
-            print("Excepción no considerada")
+            print(f"Excepción no considerada readbytes {n} {e}")
             self.logger.exception(
                 "Excepción no considerada al intentar leer {e}")
             raise e
