@@ -40,10 +40,8 @@ async def run_test(loop, code, host, port, limit=2000, show=True):
                     if done:
                         if "TIME" in msg:
                             ts_gsof, source = gps_time(msg)
-                            print("TS GSOF", ts_gsof)
                             ts = now()
                             delta = ts.timestamp() - ts_gsof.timestamp()
-                            print(msg["TIME"])
                             ts_gsof, source = gps_time(msg)
                             delta = (ts - ts_gsof).total_seconds()
                             msg["DELTA_TIME"] = delta
